# This script exports Houdini camera to Adobe After Effects 8.x
# A .jsx file will be created
# You can run it as a script in AE
# ver 0.01 Andrew V.K. 

import toolutils
import hou 
import string
import math

viewer = toolutils.sceneViewer()
cam = viewer.selectObjects("Select a camera object and press Enter",
        use_existing_selection = False,
        allow_multisel = False,
        quick_select = True,
        allowed_types = ('cam'))[-1]
camName = cam.name()

dir = hou.expandString('$HIP')
dirpath = dir + '/' + camName + '.jsx'
fname = hou.ui.selectFile( start_directory = dirpath,
        file_type = hou.fileType.Any,
        collapse_sequences = False,
        multiple_select = False,
	pattern = '*.jsx',
        image_chooser   = False)
if not fname.endswith('.jsx'):
	fname = fname + '.jsx'
fp = open(fname,'w')

fps = hou.fps()
duration = hou.expandString('$TLENGTH')
fend = string.atoi(hou.expandString('$FEND'))
fstart = string.atoi(hou.expandString('$FSTART'))
resx = cam.parm('resx').eval()
resy = cam.parm('resy').eval()
aspect = cam.parm('aspect').eval()
aperture = cam.parm('aperture').eval()
focal = cam.parm('focal').eval()
fovx = 2 * math.atan((aperture/2)/focal) 
zoom = ((resx/2)/math.tan(fovx/2))
i = fstart

fp.write('var myItemCollection = app.project.items;\n')
fp.write('var myComp = myItemCollection.addComp("%s",%s,%s,%s,%s,%s);\n'%(camName,resx,resy,aspect,duration,fps))
fp.write('var myCamera = myComp.layers.addCamera("%s",[0,0]);\n'%(camName))
fp.write('myCamera.autoOrient = AutoOrientType.NO_AUTO_ORIENT;\n')
if len(cam.parm('focal').keyframes()) == 0:
	fp.write('myCamera.property("Zoom").setValue(%f);\n'%(zoom)) 
fp.write('var myNull = myComp.layers.addNull();\n')
fp.write('myNull.threeDLayer = true;\n')
fp.write('myNull.name = "Scene Scale";\n')
fp.write('myNull.property("Position").setValue([0.0,0.0,0.0]);\n')
fp.write('myNull.enabled = false;\n')
fp.write('myCamera.parent = myNull;\n')

while i <= fend:
	hou.setFrame(i)
	ftime = hou.frameToTime(i)
        wtm = cam.worldTransform()
        camt = wtm.extractTranslates("srt")
	tx = camt.__getitem__(0)
	ty = camt.__getitem__(1) * -1
	tz = camt.__getitem__(2) * -1
        camr = wtm.extractRotates("srt","zyx")
	rx = camr.__getitem__(0)
	ry = camr.__getitem__(1) * -1
	rz = camr.__getitem__(2) * -1
	fp.write('myCamera.property("X Rotation").setValueAtTime(%f,%f);\n'%(ftime,rx)) 
	fp.write('myCamera.property("Y Rotation").setValueAtTime(%f,%f);\n'%(ftime,ry)) 
	fp.write('myCamera.property("Z Rotation").setValueAtTime(%f,%f);\n'%(ftime,rz)) 
	fp.write('myCamera.property("Position").setValueAtTime(%f,[%f,%f,%f]);\n'%(ftime,tx,ty,tz)) 
	if len(cam.parm('focal').keyframes()) != 0:
		focal = cam.parm('focal').eval()
		fovx = 2 * math.atan((aperture/2)/focal) 
		zoom = ((resx/2)/math.tan(fovx/2))
		fp.write('myCamera.property("Zoom").setValueAtTime(%f,%f);\n'%(ftime,zoom)) 
	i = i + 1
fp.close()
hou.setFrame(fstart)